# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| >= 0.4  | :white_check_mark: |
| < 0.4   | :x:                |

## Reporting a Vulnerability

Please report security vulnerabilities privately using [GitHub's security advisory feature](https://github.com/ivanostanin/lucius-mcp/security/advisories/new).

Do not open public issues for security concerns.
